# py_topping, a topping on some already great libraries
## I create this library to make my team's projects easier and have VCS

You could see samples of how to use this library inside the samples folder in github<br>
[Click Here](https://github.com/chanon-kr/Shared_Function)

<font color='red'>I'm not provide required libraries for you because of the topping concept,<br> 
I don't think it's a good idea to install every libraries to everyone.</font>

***
## data_connection
***
### sharepoint
  - to download file from SP365
  - to read csv/excel from SP365 as pandas dataframe
  - to download List as csv or pandas dataframe from SP365
  - upload file to SP365

***
### database
  - to read view, table or store procedure as pandas dataframe
  - to insert pandas dataframe into SQL with option for existing row :
    - Replace same key(s) with new from dataframe with option to use ">" or "<" condition
    - Add Only row with non-existing key(s)
    - Replace whole table

***
## general_use

### general_use
  - to send email with python
  - to logging in csv file